#
#-########################################################################
#
# Modified amap versions - ASCII Map Methods_old_style that have been re-written to make them more readable:
#
#-########################################################################
#

#
# The characters 'A'-'Z' are mapped to numbers 10-35.
# The characters '0'-'9' are mapped to numbers 0-9.
# An ampersand character ['&'] is mapped to number 36.
#
# Any other character is mapped to 0.
#
# Result is an integer.
#
def amap_1(a)

	case (a)
		when ("&"): 36
		when ("0".."9"): a.to_i
		when ("A".."Z"): a[0] - 55
		else 0
	end
end

#
# The characters 'A'-'Z' are mapped to the strings '01'-'26'.
# A comma character [','] is mapped to string '27'.
# A hyphen character ['-'] is mapped to string '28'.
# An apostrophe character ['''] is mapped to string '29'.
#
# Any other character is mapped to string '00'.
#
# Result is a string.
#
def amap_2(a)

	case (a)
		when (","): "27"
		when ("-"): "28"
		when ("'"): "29"
		when ("A".."Z"): '%02i' % (a[0] - 64)
		else "00"
	end
end

#
# The characters 'A'-'Z' are mapped to the strings '01'-'26'.
#
# Any other character is mapped to string '00'.
#
# Result is a string.
#
def amap_3(a)

	'%02i' % (("A".."Z").include?(a) ? a[0] - 64 : 0)
end

#
# The characters 'A'-'Z' are mapped to the strings '01'-'26'.
# The characters '0'-'9' are mapped to the strings '30'-'39'.
#
# Any other character is mapped to string '00'.
#
# Result is a string.
#
def amap_4(a)

	case (a)
		when ("0".."9"): (a[0] - 18).to_s
		when ("A".."Z"): '%02i' % (a[0] - 64)
		else "00"
	end
end

#
# The characters 'A'-'Z' are mapped to numbers 65-90.
# The characters '0'-'9' are mapped to numbers 48-57.
# An ampersand character ['&'] is mapped to number 38.
# A space character [' '] is mapped to number 32.
# A hyphen character ['-'] is mapped to number 45.
#
# Any other character is mapped to 0.
#
# Result is an integer.
#
def amap_5(a)

	(a =~ /^[A-Z0-9& -]$/ ? a[0] : 0)
end

#
# The characters 'A'-'I' and 'J'-'R' are mapped to numbers 1-9.
# The characters 'S'-'Z' are mapped to numbers 2-9.
# The characters '0'-'9' are mapped to numbers 0-9.
#
# Any other character is mapped to 0.
#
# Result is an integer.
#
def amap_6(a)

	case (a)
		when ("0".."9"): a.to_i
		when ("A".."I"): a[0] - 64
		when ("J".."R"): a[0] - 73
		when ("S".."Z"): a[0] - 81
		else 0
	end
end

#
# The characters 'A'-'Z' are mapped to strings '10'-'35'.
# The characters '0'-'9' are mapped to the two-digit strings '00'-'09'.
# An ampersand character ['&'] is mapped to string '36'.
#
# Any other character is mapped to string '00'.
#
# Result is a string.
#
def amap_7(a)

	case (a)
		when ("&"): "36"
		when ("0".."9"): "0#{a}"
		when ("A".."Z"): (a[0] - 55).to_s
		else "00"
	end
end

#
# The characters 'A'-'Z' are mapped to numbers 10-35.
# The characters '0'-'9' are mapped to numbers 0-9.
# An ampersand character ['&'] is mapped to number 36.
#
# Any other character is mapped to number 37.
#
# Result is an integer.
#
def amap_8(a)

	case (a)
		when ("&"): 36
		when ("0".."9"): a.to_i
		when ("A".."Z"): a[0] - 55
		else 37
	end
end

#
# The characters 'A'-'I' and 'K'-'S' are mapped to numbers 1-9.
# The characters 'U'-'Z' are mapped to numbers 1-6.
# The characters '0'-'9' are mapped to numbers 0-9.
#
# Any other character is mapped to 0.
#
# Result is an integer.
#
def amap_9(a)

	case (a)
		when ("0".."9"): a.to_i
		when ("A".."I"): a[0] - 64
		when ("K".."S"): a[0] - 74
		when ("U".."Z"): a[0] - 84
		else 0
	end
end

#
# The characters 'A'-'Z' are mapped to numbers 10-35.
# The characters '0'-'9' are mapped to numbers 0-9.
# An ampersand character ['&'] is mapped to number 36.
# A space character [' '] is mapped to 0.
#
# Any other character is mapped to number 37.
#
# Result is an integer.
#
def amap_10(a)

	case (a)
		when (" "): 0
		when ("&"): 36
		when ("0".."9"): a.to_i
		when ("A".."Z"): a[0] - 55
		else 37
	end
end

#
# A '0' character is mapped to the number 10.
# The characters '1'-'9' are mapped to numbers 1-9.
# The characters 'A'-'H' are mapped to numbers 11-18.
# The characters 'J'-'N' are mapped to numbers 19-23.
# The characters 'P'-'R' are mapped to numbers 24-26.
# The characters 'T'-'U' are mapped to numbers 27-28.
# The characters 'W'-'Y' are mapped to numbers 29-31. 
#
# Any other character is mapped to 0.
#
# Result is an integer.
#
def delaware_amap(a)

	case (a)
		when ("0"): 10
		when ("1".."9"): a.to_i
		when ("A".."H"): a[0] - 54
		when ("J".."N"): a[0] - 55
		when ("P".."R"): a[0] - 56
		when ("T".."U"): a[0] - 57
		when ("W".."Y"): a[0] - 58
		else 0
	end
end

#
# This is the reverse of the delaware_amap( ) method. For example, delaware_amap( )
# converts an 'A' to the number 11, this routine will revert the number 11 back to the
# letter 'A'.
#
# The number 10 is mapped to character '0'.
# The numbers 1-9 are mapped to characters '1'-'9'.
# The numbers 11-18 are mapped to characters 'A'-'H'.
# The numbers 19-23 are mapped to characters 'J'-'N'.
# The numbers 24-26 are mapped to characters 'P'-'R'.
# The numbers 27-28 are mapped to characters 'T'-'U'.
# The numbers 29-31 are mapped to characters 'W'-'Y'. 
#
# Any other number is mapped to the character '0'.
#
# Result is a string.
#
def delaware_cd(a)

	(case (a)
		when (1..9): a + 48
		when (11..18): a + 54
		when (19..23): a + 55
		when (24..26): a + 56
		when (27..28): a + 57
		when (29..31): a + 58
		else 48
	end).chr
end

#
# The characters 'A'-'Z' are mapped to numbers 10 - 35.
# The characters '0'-'9' are mapped to numbers 0-9.
# A hyphen character ['-'] is mapped to number 36.
# A period character ['.'] is mapped to number 37.
# A space character [' '] is mapped to number 38.
# A dollar sign character ['$'] is mapped to number 39.
# A slash character ['/'] is mapped to number 40.
# A plus sign character ['+'] is mapped to number 41.
# A percent sign character ['%'] is mapped to number 42.
#
# Any other character is mapped to 0.
#
# Result is an integer.
#
def fed_amap(a)

	case (a)
		when (" "): 38
		when ("$"): 39
		when ("%"): 42
		when ("+"): 41
		when ("-"): 36
		when ("."): 37
		when ("/"): 40
		when ("0".."9"): a.to_i
		when ("A".."Z"): a[0] - 55
		else 0
	end
end

#
# This is the reverse of the fed_amap( ) method. For example, fed_amap( ) converts an 'A' to 
# the number 10, this routine will revert the number 10 back to the letter 'A'.
#
# The numbers 10 - 35 are mapped to characters 'A'-'Z'.
# The numbers 0-9 are mapped to characters '0'-'9'.
# The  number 36 is mapped to the hyphen character ['-'].
# The number 37 is mapped to the period character ['.'].
# The number 38 is mapped to the space character [' '].
# The number 39 is mapped to the dollar sign character ['$'].
# The number 40 is mapped to the slash character ['/'].
# The number 41 is mapped to the plus sign character ['+'].
# The number 42 is mapped to the percent sign character ['%'].
#
# Any other number is mapped to the character '0'.
#
# Result is a string.
#
def fed5500_cd(a)

	case (a)
		when (38): " "
		when (39): "$"
		when (42): "%"
		when (41): "+"
		when (36): "-"
		when (37): "."
		when (40): "/"
		when (0..9): a.to_s
		when (10..35): (a + 55).chr
		else "0"
	end
end

#
# The characters 'A'-'Z' are mapped to numbers 1-26.
# The characters '0'-'9' are mapped to numbers 0-9.
#
# Any other character is mapped to 0.
#
# Result is an integer.
#
# NOTE: This routine seems wierd in that some characters get
# mapped to the same value [not talking about the default value of zero].
#
def utah_amap(a)

	case (a)
		when ("0".."9"): a.to_i
		when ("A".."Z"): a[0] - 64
		else 0
	end
end